#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/27 上午1:29
# @Desc     ：


from pydantic import BaseModel, Field


class UploadFileModel(BaseModel):
    name: str = Field(..., description="文件名")
    size: int = Field(None, description="文件大小")
    upload_time: str = Field(None, description="上传时间")



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/7/9 下午3:02
# @Desc     ：

import os
from datetime import datetime
from typing import List

from fastapi import UploadFile, File, HTTPException

from shudaodao_core import logging, CoreUtil, DiskEngine
from ..entity.upload import UploadFileModel


class UploadService:
    def __init__(self, path_name: str, disk_name: str = "Upload"):
        self._disk_name = disk_name
        self._path_name = path_name
        self._storage = DiskEngine()

    def get_file_path(self, file_name: str):
        # 目录
        storage_path = self._storage.get_path(self._disk_name, self._path_name)
        # 文件
        file_path = storage_path / file_name
        # 存在
        if os.path.exists(file_path):
            return file_path
        # 不存在
        return None

    def list_files(self):  # -> List[UploadFileModel]:
        files_info = []
        # 目录
        storage_path = self._storage.get_path(self._disk_name, self._path_name)
        for file_name in os.listdir(storage_path):
            file_path = os.path.join(storage_path, file_name)
            # 跳过目录
            if not os.path.isfile(file_path):
                continue
            files_info.append(UploadFileModel(
                name=file_name,
                size=os.path.getsize(file_path),
                upload_time=datetime.fromtimestamp(os.path.getctime(file_path)).isoformat()
            ))
        # 按日期排序
        files_info = sorted(files_info, key=lambda s: s.upload_time)
        total_files = len(files_info)
        # raise HTTPException(status_code=400, detail="aaaa")
        return {
            "status": "success",
            "message": f"成功获取 {total_files} 个文件",
            "files": files_info,
            "total_files": total_files,
        }

    async def save_files(self, files: List[UploadFile] = File(...)):
        """上传到web路径的upload"""
        file_info = []
        # 目录
        storage_path = self._storage.get_path(self._disk_name, self._path_name)
        # 格式
        allowed_extensions = {"txt", "pdf", "docx", "md"}
        """保存上传文件"""
        for file in files:
            if not any(file.filename.endswith(ext) for ext in allowed_extensions):
                raise HTTPException(status_code=400,
                                    detail=f"不支持{os.path.splitext(file.filename)[1]}")
            # 文件
            file_path = os.path.join(storage_path, file.filename)
            if os.path.exists(file_path):
                CoreUtil.remove_path(file_path)
                logging.debug(f"删除文件 --> {file_path}")
            # 保存
            with open(file_path, "wb") as buffer:
                while content := await file.read(1024 * 1024):  # 每次读取1MB
                    buffer.write(content)

            file_info.append({
                "filename": file.filename,
            })
            logging.debug(f"保存文件 --> {file_path}")
        total_files = len(file_info)
        return {
            "status": "success",
            "message": f"成功上传 {total_files} 个文件",
            "files": file_info,
            "total_files": total_files,
        }

    async def delete_files(self, files: list[UploadFileModel]):
        file_info = []
        # 目录
        storage_path = self._storage.get_path(self._disk_name, self._path_name)

        for file in files:
            file_path = storage_path / file.name
            CoreUtil.remove_path(file_path)
            file_info.append({
                "filename": file.name
            })
            logging.debug(f"删除文件 --> {file_path}")
        total_files = len(file_info)
        return {
            "status": "success",
            "message": f"成功删除 {total_files} 个文件",
            "files": file_info,
            "total_files": total_files,
        }



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/28 下午5:04
# @Desc     ：


from datetime import datetime
from typing import Optional, List

from sqlmodel import SQLModel, Field, Relationship

from shudaodao_core import get_primary_id


class UserBase(SQLModel):
    """ 基础对象 - 共用字段 """
    username: str = Field(unique=True, index=True, max_length=50)
    email: str = Field(unique=True, index=True, max_length=100)
    nickname: Optional[str] = Field(default=None, max_length=100)
    is_active: bool = Field(default=True)
    is_superuser: bool = Field(default=False)
    role: str = Field(default="user", max_length=20)


class User(UserBase, table=True):
    """ 数据模型 - 数据库表 T_User 结构模型 """
    __tablename__ = "t_user"
    user_id: Optional[int] = Field(default_factory=get_primary_id, primary_key=True)
    password: str  # 不直接暴露给API
    created_at: datetime = Field(default_factory=datetime.utcnow)
    updated_at: datetime = Field(default_factory=datetime.utcnow)
    last_login: Optional[datetime] = Field(default_factory=datetime.utcnow)
    # 关系
    tokens: List["UserToken"] = Relationship(back_populates="user")


class UserCreate(UserBase):
    """ 创建模型 - 用于[post]创建接口 """
    password: str = Field(min_length=8, alias="register-password")  # 密码不应直接存储在数据库模型中
    username: str = Field(alias="register-username")
    email: str = Field(alias="register-email")


class UserUpdate(UserBase):
    """ 更新模型 - 用于[patch]更新接口 """
    username: str = Field(None)
    updated_at: datetime = Field(None)


class UserResponse(UserBase):
    """ 响应模型 - 用于响应前端"""
    user_id: int


class UserToken(SQLModel, table=True):
    token_id: Optional[int] = Field(default_factory=get_primary_id, primary_key=True)
    token: str = Field(unique=True, index=True)
    user_id: int = Field(foreign_key="t_user.user_id")
    expires_at: datetime
    is_revoked: bool = Field(default=False)
    created_at: datetime = Field(default_factory=datetime.utcnow)
    # 关系
    user: User = Relationship(back_populates="tokens")



from ..entity_table.dept import Dept as Dept, DeptCreate as DeptCreate, DeptResponse as DeptResponse, DeptUpdate as DeptUpdate
from _typeshed import Incomplete
from shudaodao_core import AsyncSession as AsyncSession, QueryRequest as QueryRequest

Dept_Router: Incomplete

async def dept_query(*, query: QueryRequest, db: AsyncSession = ...): ...
async def dept_create(*, create_model: DeptCreate, db: AsyncSession = ...): ...
async def dept_read(*, primary_id: int, db: AsyncSession = ...): ...
async def dept_update(*, primary_id: int, model_update: DeptUpdate, db: AsyncSession = ...): ...
async def dept_delete(*, primary_id: int, db: AsyncSession = ...): ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/29 上午2:13
# @Desc     ：

from typing import Optional

from sqlmodel import SQLModel, Field

from shudaodao_core import get_primary_id


class DeptBase(SQLModel):
    dept_id: Optional[int] = Field(default_factory=get_primary_id, primary_key=True)
    dept_name: str = Field(max_length=100, description="部门名称")


class Dept(DeptBase, table=True):
    __tablename__ = "t_dept"
    __table_args__ = {"schema": "shudao_acm", "comment": "部门表"}


class DeptCreate(DeptBase):
    ...


class DeptResponse(DeptBase):
    ...


class DeptUpdate(DeptBase):
    ...



from dataclasses import dataclass

@dataclass
class GeneratorConfig:
    db_url: str
    output_schema_to_entity: bool
    output_db_engine_name: str
    output_auth_role_name: str | None = ...
    output_router_path: str | None = ...
    output_path: str | None = ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/7/7 下午8:32
# @Desc     ：

from typing import List

from fastapi import UploadFile, File

from shudaodao_core import AuthRouter
from ..entity.upload import UploadFileModel
from ..service.upload import UploadService

Upload_Router = AuthRouter(
    prefix="/v1/files",
    tags=["通用功能"]
)


# 获取目录下所有文件列表
@Upload_Router.get("/{path_name}")
async def get_files(path_name: str):
    return UploadService(path_name).list_files()


# 多文件上传到目录
@Upload_Router.post("/{path_name}")
async def upload(path_name: str, files: List[UploadFile] = File(...), ):
    return await UploadService(path_name).save_files(files)


# 删除多文件
@Upload_Router.delete("/{path_name}")
async def delete_file(path_name: str, files: list[UploadFileModel]):
    return await UploadService(path_name).delete_files(files)



from ..auth.auth_router import AuthRouter as AuthRouter
from ..entity.auth_user import AuthLogin as AuthLogin, AuthPassword as AuthPassword, AuthRegister as AuthRegister, AuthUser as AuthUser
from ..services.auth_service import AuthService as AuthService
from ..services.data_service import DataService as DataService
from ..utils.response_utils import ResponseUtil as ResponseUtil
from _typeshed import Incomplete
from fastapi import Request as Request
from fastapi.security import OAuth2PasswordRequestForm as OAuth2PasswordRequestForm
from sqlmodel.ext.asyncio.session import AsyncSession as AsyncSession

Auth_Controller: Incomplete

async def auth_register(register_model: AuthRegister, db: AsyncSession = ...): ...
async def auth_login(login_model: AuthLogin, db: AsyncSession = ...): ...
async def auth_token(request: Request, form_data: OAuth2PasswordRequestForm = ..., db: AsyncSession = ...): ...
async def auth_logout(): ...
async def auth_refresh(): ...
async def auth_me(current_user: AuthUser = ...): ...
async def auth_me_password(password_model: AuthPassword, db: AsyncSession = ..., current_user: AuthUser = ...): ...



from .meta_column import MetaColumn as MetaColumn
from dataclasses import dataclass
from sqlalchemy import inspect as inspect

@dataclass
class MetaTable:
    inspector = ...
    schema_name = ...
    router_path = ...
    table_or_view_name = ...
    file_name = ...
    class_name = ...
    columns: list[MetaColumn] = ...
    comment: str = ...
    generated_date: str = ...
    entity_imports: list[str] = ...
    table_args: str = ...
    def __init__(self, *, inspector: inspect, table_or_view_name, schema_name, output_entity_schema, router_path) -> None: ...
    def get_columns(self) -> list[MetaColumn]: ...
    @staticmethod
    def get_sa_type(column_type, is_primary: bool) -> str: ...
    def get_comment(self): ...
    def get_import_field(self) -> str: ...



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/9/17 上午11:06
# @Desc     ：

from typing import Optional

from sqlmodel import SQLModel, Field


class AuthRule(SQLModel, table=True):
    __tablename__ = "t_auth_rule"
    id: Optional[int] = Field(default=None, primary_key=True)
    ptype: Optional[str] = Field(max_length=32, alias="ptype")  # 代替 ptype，如 "p" 或 "g"
    v0: Optional[str] = Field(max_length=255)  # 代替 v0
    v1: Optional[str] = Field(max_length=255)  # 代替 v1
    v2: Optional[str] = Field(max_length=255)  # 代替 v2
    v3: Optional[str] = Field(max_length=255)  # 自定义字段
    v4: Optional[str] = Field(max_length=255)  # 自定义字段
    v5: Optional[str] = Field(max_length=255)  # 自定义字段

    # rule_id: Optional[int] = Field(default=None, primary_key=True, alias="id")
    # policy_type: Optional[str] = Field(max_length=32, alias="ptype")  # 代替 ptype，如 "p" 或 "g"
    # subject: Optional[str] = Field(max_length=255,alias="v0")  # 代替 v0
    # object: Optional[str] = Field(max_length=255,alias="v1") # 代替 v1
    # action: Optional[str] = Field(max_length=255,alias="v2")  # 代替 v2
    # description: Optional[str] = Field(max_length=255,alias="v3")  # 自定义字段

    def __repr__(self):
        return f"<CasbinRule {self.ptype}, {self.v0}, {self.v1}, {self.v2}>"



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/18 下午7:43
# @Desc     ：

from typing import Any, Dict
from typing import Optional

from pydantic import Field, BaseModel
from sqlalchemy import BigInteger
from sqlmodel import SQLModel


class BaseResponse(SQLModel):
    """
    自动将所有 sa_type=BigInteger 的字段，在 model_dump() 时转为字符串。
    支持嵌套模型递归转换。
    不新增字段，直接原地替换值类型。
    """

    def model_dump(self, *args, **kwargs) -> Dict[str, Any]:
        # 先获取原始 dump 结果（不包含嵌套模型的转换）
        data = super().model_dump(*args, **kwargs)

        # 遍历所有字段定义
        for field_name, field_info in self.model_fields.items():
            # value = data.get(field_name)  # 从原始数据字典获取 无法进行实例判断
            value = getattr(self, field_name)  # 从模型实例获取 才能判断类型
            # 情况1: 该字段是 sa_type=BigInteger → 转为字符串
            if hasattr(field_info, 'sa_type') and field_info.sa_type is BigInteger:
                if value is not None:
                    data[field_name] = str(value)

            # 情况2: 该字段值是 BaseReadModel 的实例 → 递归转换
            elif isinstance(value, BaseResponse):
                data[field_name] = value.model_dump(*args, **kwargs)

            # 情况3: 该字段是列表，且元素是 BaseReadModel → 递归转换每个元素
            # 查询接口已经处理过了

        return data

    # 兼容 Pydantic v1 / jsonable_encoder
    def dict(self, *args, **kwargs) -> Dict[str, Any]:
        return self.model_dump(*args, **kwargs)


class DataResponse(BaseResponse):
    success: bool = True
    code: int = Field(200, description="Response code")
    name: Optional[str] = None
    message: str = ""
    data: Optional[Any] = None


class ErrorResponse(BaseModel):
    success: bool = True
    code: int = Field(..., description="Response code")
    name: Optional[str] = None
    message: str = ""
    error: Optional[Any] = None



from ..entity_table.user import User as User, UserCreate as UserCreate, UserResponse as UserResponse, UserUpdate as UserUpdate
from _typeshed import Incomplete
from shudaodao_core import AsyncSession as AsyncSession, QueryRequest as QueryRequest

User_Router: Incomplete

async def user_create(*, create_model: UserCreate, db: AsyncSession = ...): ...
async def user_read(*, primary_id: int, db: AsyncSession = ...): ...
async def user_update(*, primary_id: int, update_model: UserUpdate, db: AsyncSession = ...): ...
async def user_delete(*, primary_id: int, db: AsyncSession = ...): ...
async def user_query(*, query: QueryRequest, db: AsyncSession = ...): ...



from ..config.app_config import AppConfig as AppConfig
from _typeshed import Incomplete
from enum import Enum

class LoggingLevel(Enum):
    DEBUG: int
    INFO: int
    WARNING: int
    ERROR: int

class _Logger:
    line_length: int
    logger: Incomplete
    def __init__(self) -> None: ...
    def info(self, message: object, *args, **kwargs) -> None: ...
    def info_line(self) -> None: ...
    def debug(self, message: object, *args, **kwargs) -> None: ...
    def debug_line(self) -> None: ...
    def warning(self, message: object, *args, **kwargs) -> None: ...
    def error(self, message: object, *args, **kwargs) -> None: ...

logging: Incomplete



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/29 下午3:57
# @Desc     ：

from typing import Optional

from sqlmodel import SQLModel, Field


class DeptUserBase(SQLModel):
    name: Optional[str]
    email: Optional[str]
    username: Optional[str]
    full_name: Optional[str]


class DeptUser(SQLModel, table=True):
    __tablename__ = 'v_dept_user'
    user_id: int = Field(primary_key=True)



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技
# @Author   ：李锋
# @Software ：PyCharm
# @Date     ：2025/8/27 上午1:29
# @Desc     ：

from .controller_table.dept import Dept_Router
from .controller_table.user import User_Router
from .shared.controller.upload import Upload_Router
from .shared.service.upload import UploadService



import abc
from ..auth.auth_router import AuthRouter as AuthRouter
from ..config.app_config import AppConfig as AppConfig
from ..logger.logging_ import logging as logging
from ..services.premission_service import PermissionService as PermissionService
from ..tools.class_scaner import ClassScanner as ClassScanner
from ..utils.core_utils import CoreUtil as CoreUtil
from _typeshed import Incomplete
from abc import ABC, abstractmethod

class BaseApplication(ABC, metaclass=abc.ABCMeta):
    app: Incomplete
    def __init__(self) -> None: ...
    @abstractmethod
    def application_onload(self): ...
    @abstractmethod
    def application_unload(self): ...
